@@ -3,7 +3,7 @@
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2022 Eggheads Development Team
+ * Copyright (C) 1999 - 2023 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1720,25 +1720,17 @@ static int tcl_channel_modify(Tcl_Interp *irp, struct chanset_t *chan,
 static int tcl_do_masklist(maskrec *m, Tcl_Interp *irp)
 {
   char ts[21], ts1[21], ts2[21], *p;
-  long tv;
   EGG_CONST char *list[6];
 
   for (; m; m = m->next) {
     list[0] = m->mask;
     list[1] = m->desc;
-
-    tv = m->expire;
-    sprintf(ts, "%lu", tv);
+    snprintf(ts, sizeof ts, "%" PRId64, (int64_t) m->expire);
     list[2] = ts;
-
-    tv = m->added;
-    sprintf(ts1, "%lu", tv);
+    snprintf(ts1, sizeof ts1, "%" PRId64, (int64_t) m->added);
     list[3] = ts1;
-
-    tv = m->lastactive;
-    sprintf(ts2, "%lu", tv);
+    snprintf(ts2, sizeof ts2, "%" PRId64, (int64_t) m->lastactive);
     list[4] = ts2;
-
     list[5] = m->user;
     p = Tcl_Merge(6, list);
     Tcl_AppendElement(irp, p);
@@ -2290,7 +2282,7 @@ static int tcl_deludef STDVAR
 static int tcl_getudefs STDVAR
 {
   struct udef_struct *ul;
-  int type = 0, count = 0;
+  int type = 0;
 
   BADARGS(1, 2, " ?type?");
 
@@ -2310,7 +2302,6 @@ static int tcl_getudefs STDVAR
   for (ul = udef; ul; ul = ul->next)
     if (!type || (ul->type == type)) {
       Tcl_AppendElement(irp, ul->name);
-      count++;
     }
 
   return TCL_OK;
