@@ -4,7 +4,7 @@
  */
 /*
  * Copyright (C) 1997 Robey Pointer
- * Copyright (C) 1999 - 2022 Eggheads Development Team
+ * Copyright (C) 1999 - 2023 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -611,8 +611,7 @@ static int tcl_killignore STDVAR
 
 static int tcl_ignorelist STDVAR
 {
-  char expire[11], added[11], *p;
-  long tv;
+  char expire[21], added[21], *p;
   EGG_CONST char *list[5];
   struct igrec *i;
 
@@ -621,15 +620,10 @@ static int tcl_ignorelist STDVAR
   for (i = global_ign; i; i = i->next) {
     list[0] = i->igmask;
     list[1] = i->msg;
-
-    tv = i->expire;
-    egg_snprintf(expire, sizeof expire, "%lu", tv);
+    snprintf(expire, sizeof expire, "%" PRId64, (int64_t) i->expire);
     list[2] = expire;
-
-    tv = i->added;
-    egg_snprintf(added, sizeof added, "%lu", tv);
+    snprintf(added, sizeof added, "%" PRId64, (int64_t) i->added);
     list[3] = added;
-
     list[4] = i->user;
     p = Tcl_Merge(5, list);
     Tcl_AppendElement(irp, p);
